@@ -9,11 +9,11 @@ Log::Tiny - Log data with as little code as possible
 
 =head1 VERSION
 
-Version 0.9
+Version 1.0
 
 =cut
 
-$VERSION = '0.9';
+$VERSION = '1.0';
 $errstr = '';
 
 %formats = (
@@ -79,11 +79,13 @@ sub new {
     my $pkg = shift;
     my $logfile = shift || return _error('No logfile provided');
     my $format = shift || '[%t] %f:%p (%c) %m%n';
-    open ( LOG, '>>' . $logfile ) || 
+    open (my $logfh, '>>' . $logfile ) || 
         return _error( "Could not open $logfile: $!" );
     my $self = bless { 
         format => $format,
         methods_only => [],
+        logfile => $logfile,
+        logfh => $logfh,
     }, $pkg;
     $self->format();
     return $self;
@@ -198,7 +200,7 @@ sub AUTOLOAD {
     my $ret;
     {
         my $autoflush = $|++;
-        $ret = print LOG $tmp;
+        $ret = print {$self->{logfh}} $tmp;
         $| = $autoflush;
     }
     return $ret;
@@ -217,7 +219,7 @@ sub _mk_args {
     return @ret;
 }
 
-sub DESTROY { close LOG or warn "Couldn't close log file: $!"; }
+sub DESTROY { close shift->{logfh} or warn "Couldn't close log file: $!"; }
 
 =head2 errstr
 
@@ -278,16 +280,20 @@ L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Log-Tiny>
 
 L<http://search.cpan.org/dist/Log-Tiny>
 
+=item * GitHub
+
+L<https://github.com/jmadler/p5-log-tiny>
+
 =back
 
 =head1 ACKNOWLEDGEMENTS
 
 Much thanks to Michael Schilli C<CPAN:mschilli> for his great work on 
-Log::Log4perl.
+Log::Log4perl, of which this module's formatting concept is largely based upon.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2007-2010 Jordan M. Adler, all rights reserved.
+Copyright 2007-2015 Jordan M. Adler, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
